devtui

package module
v0.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2025 License: MIT Imports: 12 Imported by: 0

README

devtui

interactive terminal user interface focused on developing applications

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ColorStyle

type ColorStyle struct {
	ForeGround string // eg: #F4F4F4
	Background string // eg: #000000
	Highlight  string // eg: #FF6600
	Lowlight   string // eg: #666666
}

type DevTUI

type DevTUI struct {
	*TuiConfig

	SectionFooter string
	// contains filtered or unexported fields
}

DevTUI mantiene el estado de la aplicación

func NewTUI

func NewTUI(c *TuiConfig) *DevTUI

func (*DevTUI) ContentView

func (h *DevTUI) ContentView() string

ContentView renderiza los mensajes para una sección de contenido

func (*DevTUI) Init

func (h *DevTUI) Init() tea.Cmd

Init initializes the terminal UI application.

func (*DevTUI) InitTUI added in v0.0.5

func (h *DevTUI) InitTUI(args ...any)

InitTUI initializes and runs the terminal UI application.

It accepts optional variadic arguments of any type. If a *sync.WaitGroup is provided among these arguments, InitTUI will call its Done() method before returning.

The method runs the UI using the internal tea engine, and handles any errors that may occur during execution. If an error occurs, it will be displayed on the console and the application will wait for user input before exiting.

Parameters:

  • args ...any: Optional arguments. Can include a *sync.WaitGroup for synchronization.

func (*DevTUI) Print

func (h *DevTUI) Print(messages ...any)

Print sends a normal Label or error to the tui in current tab

func (*DevTUI) ReturnFocus

func (t *DevTUI) ReturnFocus() error

func (*DevTUI) Update

func (h *DevTUI) Update(msg tea.Msg) (tea.Model, tea.Cmd)

Update maneja las actualizaciones del estado

func (*DevTUI) View

func (h *DevTUI) View() string

type FieldHandler added in v0.0.7

type FieldHandler struct {
	Name             string                                               // eg: "port", "Server Port", "8080"
	Label            string                                               // eg: "Server Port"
	Value            string                                               // eg: "8080"
	Editable         bool                                                 // if no editable eject the action FieldValueChange directly
	FieldValueChange func(newValue string) (runMessage string, err error) //eg: "8080" -> "9090" runMessage: "Port changed from 8080 to 9090"
	// contains filtered or unexported fields
}

Interface for handling tab field sectionFields

func (*FieldHandler) SetCursorAtEnd added in v0.0.7

func (cf *FieldHandler) SetCursorAtEnd()

type TabSection

type TabSection struct {
	Title         string         // eg: "BUILD", "TEST"
	FieldHandlers []FieldHandler // Field actions configured for the section
	SectionFooter string         // eg: "Press 't' to compile", "Press 'r' to run tests"
	// contains filtered or unexported fields
}

represent the tab section in the tui

func (*TabSection) Write added in v0.0.4

func (ts *TabSection) Write(p []byte) (n int, err error)

Write implementa io.Writer para capturar la salida de otros procesos

type TuiConfig

type TuiConfig struct {
	TabIndexStart int          // is the index of the tab to start
	ExitChan      chan bool    //  global chan to close app
	TabSections   []TabSection // represent sections in the tui
	Color         *ColorStyle

	LogToFile func(messageErr string) // function to write log error
}

Jump to