Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ColorStyle ¶
type DevTUI ¶
type DevTUI struct {
*TuiConfig
// contains filtered or unexported fields
}
DevTUI mantiene el estado de la aplicación
func (*DevTUI) ContentView ¶
ContentView renderiza los mensajes para una sección de contenido
func (*DevTUI) InitTUI ¶ added in v0.0.5
InitTUI initializes and runs the terminal UI application.
It accepts optional variadic arguments of any type. If a *sync.WaitGroup is provided among these arguments, InitTUI will call its Done() method before returning.
The method runs the UI using the internal tea engine, and handles any errors that may occur during execution. If an error occurs, it will be displayed on the console and the application will wait for user input before exiting.
Parameters:
- args ...any: Optional arguments. Can include a *sync.WaitGroup for synchronization.
func (*DevTUI) ReturnFocus ¶
type FieldHandler ¶ added in v0.0.7
type FieldHandler struct {
Name string // eg: "port", "Server Port", "8080"
Label string // eg: "Server Port"
Value string // eg: "8080"
Editable bool // if no editable eject the action FieldValueChange directly
FieldValueChange func(newValue string) (runMessage string, err error) //eg: "8080" -> "9090" runMessage: "Port changed from 8080 to 9090"
// contains filtered or unexported fields
}
Interface for handling tab field sectionFields
func (*FieldHandler) SetCursorAtEnd ¶ added in v0.0.7
func (cf *FieldHandler) SetCursorAtEnd()
type TabSection ¶
type TabSection struct {
Title string // eg: "BUILD", "TEST"
FieldHandlers []FieldHandler // Field actions configured for the section
// contains filtered or unexported fields
}
represent the tab section in the tui
type TuiConfig ¶
type TuiConfig struct {
TabIndexStart int // is the index of the tab to start
ExitChan chan bool // global chan to close app
TabSections []TabSection // represent sections in the tui
Color *ColorStyle
LogToFile func(messageErr string) // function to write log error
}